==> org.eclipse.wb.core.databinding.xsd.source_1.0.0.202401190510.jar: org/eclipse/wb/core/databinding/xsd/component/ObjectFactory.java <==

package org.eclipse.wb.core.databinding.xsd.component;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.eclipse.wb.core.databinding.xsd.component package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ExposingRulesTypeExclude_QNAME = new QName("http://www.eclipse.org/wb/WBPComponent", "exclude");
    private final static QName _ExposingRulesTypeInclude_QNAME = new QName("http://www.eclipse.org/wb/WBPComponent", "include");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.eclipse.wb.core.databinding.xsd.component
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Component }
     * 
     */
    public Component createComponent() {
        return new Component();
    }

    /**
     * Create an instance of {@link Factory }
     * 
     */
    public Factory createFactory() {
        return new Factory();
    }

    /**
     * Create an instance of {@link ParameterBaseType }
     * 
     */
    public ParameterBaseType createParameterBaseType() {
        return new ParameterBaseType();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements }
     * 
     */
    public PropertyConfigurationElements createPropertyConfigurationElements() {
        return new PropertyConfigurationElements();
    }

    /**
     * Create an instance of {@link Factory.Method }
     * 
     */
    public Factory.Method createFactoryMethod() {
        return new Factory.Method();
    }

    /**
     * Create an instance of {@link Factory.Method.Parameters }
     * 
     */
    public Factory.Method.Parameters createFactoryMethodParameters() {
        return new Factory.Method.Parameters();
    }

    /**
     * Create an instance of {@link Component.Parameters }
     * 
     */
    public Component.Parameters createComponentParameters() {
        return new Component.Parameters();
    }

    /**
     * Create an instance of {@link MorphingType }
     * 
     */
    public MorphingType createMorphingType() {
        return new MorphingType();
    }

    /**
     * Create an instance of {@link MethodsOrderType }
     * 
     */
    public MethodsOrderType createMethodsOrderType() {
        return new MethodsOrderType();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Methods }
     * 
     */
    public MethodsOrderType.Methods createMethodsOrderTypeMethods() {
        return new MethodsOrderType.Methods();
    }

    /**
     * Create an instance of {@link Component.Methods }
     * 
     */
    public Component.Methods createComponentMethods() {
        return new Component.Methods();
    }

    /**
     * Create an instance of {@link Component.Constructors }
     * 
     */
    public Component.Constructors createComponentConstructors() {
        return new Component.Constructors();
    }

    /**
     * Create an instance of {@link Creation }
     * 
     */
    public Creation createCreation() {
        return new Creation();
    }

    /**
     * Create an instance of {@link Component.License }
     * 
     */
    public Component.License createComponentLicense() {
        return new Component.License();
    }

    /**
     * Create an instance of {@link Component.Toolkit }
     * 
     */
    public Component.Toolkit createComponentToolkit() {
        return new Component.Toolkit();
    }

    /**
     * Create an instance of {@link Component.Model }
     * 
     */
    public Component.Model createComponentModel() {
        return new Component.Model();
    }

    /**
     * Create an instance of {@link Component.XModel }
     * 
     */
    public Component.XModel createComponentXModel() {
        return new Component.XModel();
    }

    /**
     * Create an instance of {@link ExposingRulesType }
     * 
     */
    public ExposingRulesType createExposingRulesType() {
        return new ExposingRulesType();
    }

    /**
     * Create an instance of {@link Component.PropertiesPreferred }
     * 
     */
    public Component.PropertiesPreferred createComponentPropertiesPreferred() {
        return new Component.PropertiesPreferred();
    }

    /**
     * Create an instance of {@link Component.PropertiesNormal }
     * 
     */
    public Component.PropertiesNormal createComponentPropertiesNormal() {
        return new Component.PropertiesNormal();
    }

    /**
     * Create an instance of {@link Component.PropertiesAdvanced }
     * 
     */
    public Component.PropertiesAdvanced createComponentPropertiesAdvanced() {
        return new Component.PropertiesAdvanced();
    }

    /**
     * Create an instance of {@link Component.PropertiesHidden }
     * 
     */
    public Component.PropertiesHidden createComponentPropertiesHidden() {
        return new Component.PropertiesHidden();
    }

    /**
     * Create an instance of {@link Component.PropertiesNoDefaultValue }
     * 
     */
    public Component.PropertiesNoDefaultValue createComponentPropertiesNoDefaultValue() {
        return new Component.PropertiesNoDefaultValue();
    }

    /**
     * Create an instance of {@link Component.PropertyTag }
     * 
     */
    public Component.PropertyTag createComponentPropertyTag() {
        return new Component.PropertyTag();
    }

    /**
     * Create an instance of {@link Component.MethodSingleProperty }
     * 
     */
    public Component.MethodSingleProperty createComponentMethodSingleProperty() {
        return new Component.MethodSingleProperty();
    }

    /**
     * Create an instance of {@link Component.MethodProperty }
     * 
     */
    public Component.MethodProperty createComponentMethodProperty() {
        return new Component.MethodProperty();
    }

    /**
     * Create an instance of {@link PropertyConfiguration }
     * 
     */
    public PropertyConfiguration createPropertyConfiguration() {
        return new PropertyConfiguration();
    }

    /**
     * Create an instance of {@link ConfigurablePropertyType }
     * 
     */
    public ConfigurablePropertyType createConfigurablePropertyType() {
        return new ConfigurablePropertyType();
    }

    /**
     * Create an instance of {@link TypeParametersType }
     * 
     */
    public TypeParametersType createTypeParametersType() {
        return new TypeParametersType();
    }

    /**
     * Create an instance of {@link TypeParameterType }
     * 
     */
    public TypeParameterType createTypeParameterType() {
        return new TypeParameterType();
    }

    /**
     * Create an instance of {@link XAttributeType }
     * 
     */
    public XAttributeType createXAttributeType() {
        return new XAttributeType();
    }

    /**
     * Create an instance of {@link MethodParameter }
     * 
     */
    public MethodParameter createMethodParameter() {
        return new MethodParameter();
    }

    /**
     * Create an instance of {@link PropertyEditor }
     * 
     */
    public PropertyEditor createPropertyEditor() {
        return new PropertyEditor();
    }

    /**
     * Create an instance of {@link ExposingRuleType }
     * 
     */
    public ExposingRuleType createExposingRuleType() {
        return new ExposingRuleType();
    }

    /**
     * Create an instance of {@link TagType }
     * 
     */
    public TagType createTagType() {
        return new TagType();
    }

    /**
     * Create an instance of {@link ParameterBaseType.Parameter }
     * 
     */
    public ParameterBaseType.Parameter createParameterBaseTypeParameter() {
        return new ParameterBaseType.Parameter();
    }

    /**
     * Create an instance of {@link ParameterBaseType.ParameterList }
     * 
     */
    public ParameterBaseType.ParameterList createParameterBaseTypeParameterList() {
        return new ParameterBaseType.ParameterList();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Category }
     * 
     */
    public PropertyConfigurationElements.Category createPropertyConfigurationElementsCategory() {
        return new PropertyConfigurationElements.Category();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.DefaultValue }
     * 
     */
    public PropertyConfigurationElements.DefaultValue createPropertyConfigurationElementsDefaultValue() {
        return new PropertyConfigurationElements.DefaultValue();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Getter }
     * 
     */
    public PropertyConfigurationElements.Getter createPropertyConfigurationElementsGetter() {
        return new PropertyConfigurationElements.Getter();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Tag }
     * 
     */
    public PropertyConfigurationElements.Tag createPropertyConfigurationElementsTag() {
        return new PropertyConfigurationElements.Tag();
    }

    /**
     * Create an instance of {@link Factory.Method.Invocation }
     * 
     */
    public Factory.Method.Invocation createFactoryMethodInvocation() {
        return new Factory.Method.Invocation();
    }

    /**
     * Create an instance of {@link Factory.Method.Parameters.Parameter }
     * 
     */
    public Factory.Method.Parameters.Parameter createFactoryMethodParametersParameter() {
        return new Factory.Method.Parameters.Parameter();
    }

    /**
     * Create an instance of {@link Component.Parameters.Parameter }
     * 
     */
    public Component.Parameters.Parameter createComponentParametersParameter() {
        return new Component.Parameters.Parameter();
    }

    /**
     * Create an instance of {@link MorphingType.MorphTarget }
     * 
     */
    public MorphingType.MorphTarget createMorphingTypeMorphTarget() {
        return new MorphingType.MorphTarget();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Default }
     * 
     */
    public MethodsOrderType.Default createMethodsOrderTypeDefault() {
        return new MethodsOrderType.Default();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Method }
     * 
     */
    public MethodsOrderType.Method createMethodsOrderTypeMethod() {
        return new MethodsOrderType.Method();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Methods.S }
     * 
     */
    public MethodsOrderType.Methods.S createMethodsOrderTypeMethodsS() {
        return new MethodsOrderType.Methods.S();
    }

    /**
     * Create an instance of {@link Component.Methods.MethodsInclude }
     * 
     */
    public Component.Methods.MethodsInclude createComponentMethodsMethodsInclude() {
        return new Component.Methods.MethodsInclude();
    }

    /**
     * Create an instance of {@link Component.Methods.MethodsExclude }
     * 
     */
    public Component.Methods.MethodsExclude createComponentMethodsMethodsExclude() {
        return new Component.Methods.MethodsExclude();
    }

    /**
     * Create an instance of {@link Component.Methods.Method }
     * 
     */
    public Component.Methods.Method createComponentMethodsMethod() {
        return new Component.Methods.Method();
    }

    /**
     * Create an instance of {@link Component.Constructors.Constructor }
     * 
     */
    public Component.Constructors.Constructor createComponentConstructorsConstructor() {
        return new Component.Constructors.Constructor();
    }

    /**
     * Create an instance of {@link Creation.Invocation }
     * 
     */
    public Creation.Invocation createCreationInvocation() {
        return new Creation.Invocation();
    }

    /**
     * Create an instance of {@link Creation.Parameter }
     * 
     */
    public Creation.Parameter createCreationParameter() {
        return new Creation.Parameter();
    }

    /**
     * Create an instance of {@link Creation.XContent }
     * 
     */
    public Creation.XContent createCreationXContent() {
        return new Creation.XContent();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.eclipse.org/wb/WBPComponent", name = "exclude", scope = ExposingRulesType.class)
    public JAXBElement<ExposingRuleType> createExposingRulesTypeExclude(ExposingRuleType value) {
        return new JAXBElement<ExposingRuleType>(_ExposingRulesTypeExclude_QNAME, ExposingRuleType.class, ExposingRulesType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.eclipse.org/wb/WBPComponent", name = "include", scope = ExposingRulesType.class)
    public JAXBElement<ExposingRuleType> createExposingRulesTypeInclude(ExposingRuleType value) {
        return new JAXBElement<ExposingRuleType>(_ExposingRulesTypeInclude_QNAME, ExposingRuleType.class, ExposingRulesType.class, value);
    }

}

==> org.eclipse.wb.core.databinding.xsd.source_1.1.0.202601140522.jar: org/eclipse/wb/core/databinding/xsd/component/ObjectFactory.java <==

package org.eclipse.wb.core.databinding.xsd.component;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.eclipse.wb.core.databinding.xsd.component package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _ExposingRulesTypeExclude_QNAME = new QName("http://www.eclipse.org/wb/WBPComponent", "exclude");
    private static final QName _ExposingRulesTypeInclude_QNAME = new QName("http://www.eclipse.org/wb/WBPComponent", "include");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.eclipse.wb.core.databinding.xsd.component
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Component }
     * 
     * @return
     *     the new instance of {@link Component }
     */
    public Component createComponent() {
        return new Component();
    }

    /**
     * Create an instance of {@link Factory }
     * 
     * @return
     *     the new instance of {@link Factory }
     */
    public Factory createFactory() {
        return new Factory();
    }

    /**
     * Create an instance of {@link ParameterBaseType }
     * 
     * @return
     *     the new instance of {@link ParameterBaseType }
     */
    public ParameterBaseType createParameterBaseType() {
        return new ParameterBaseType();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements }
     * 
     * @return
     *     the new instance of {@link PropertyConfigurationElements }
     */
    public PropertyConfigurationElements createPropertyConfigurationElements() {
        return new PropertyConfigurationElements();
    }

    /**
     * Create an instance of {@link Factory.Method }
     * 
     * @return
     *     the new instance of {@link Factory.Method }
     */
    public Factory.Method createFactoryMethod() {
        return new Factory.Method();
    }

    /**
     * Create an instance of {@link Factory.Method.Parameters }
     * 
     * @return
     *     the new instance of {@link Factory.Method.Parameters }
     */
    public Factory.Method.Parameters createFactoryMethodParameters() {
        return new Factory.Method.Parameters();
    }

    /**
     * Create an instance of {@link Component.Parameters }
     * 
     * @return
     *     the new instance of {@link Component.Parameters }
     */
    public Component.Parameters createComponentParameters() {
        return new Component.Parameters();
    }

    /**
     * Create an instance of {@link MorphingType }
     * 
     * @return
     *     the new instance of {@link MorphingType }
     */
    public MorphingType createMorphingType() {
        return new MorphingType();
    }

    /**
     * Create an instance of {@link MethodsOrderType }
     * 
     * @return
     *     the new instance of {@link MethodsOrderType }
     */
    public MethodsOrderType createMethodsOrderType() {
        return new MethodsOrderType();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Methods }
     * 
     * @return
     *     the new instance of {@link MethodsOrderType.Methods }
     */
    public MethodsOrderType.Methods createMethodsOrderTypeMethods() {
        return new MethodsOrderType.Methods();
    }

    /**
     * Create an instance of {@link Component.Methods }
     * 
     * @return
     *     the new instance of {@link Component.Methods }
     */
    public Component.Methods createComponentMethods() {
        return new Component.Methods();
    }

    /**
     * Create an instance of {@link Component.Constructors }
     * 
     * @return
     *     the new instance of {@link Component.Constructors }
     */
    public Component.Constructors createComponentConstructors() {
        return new Component.Constructors();
    }

    /**
     * Create an instance of {@link Creation }
     * 
     * @return
     *     the new instance of {@link Creation }
     */
    public Creation createCreation() {
        return new Creation();
    }

    /**
     * Create an instance of {@link Component.License }
     * 
     * @return
     *     the new instance of {@link Component.License }
     */
    public Component.License createComponentLicense() {
        return new Component.License();
    }

    /**
     * Create an instance of {@link Component.Toolkit }
     * 
     * @return
     *     the new instance of {@link Component.Toolkit }
     */
    public Component.Toolkit createComponentToolkit() {
        return new Component.Toolkit();
    }

    /**
     * Create an instance of {@link Component.Model }
     * 
     * @return
     *     the new instance of {@link Component.Model }
     */
    public Component.Model createComponentModel() {
        return new Component.Model();
    }

    /**
     * Create an instance of {@link Component.XModel }
     * 
     * @return
     *     the new instance of {@link Component.XModel }
     */
    public Component.XModel createComponentXModel() {
        return new Component.XModel();
    }

    /**
     * Create an instance of {@link ExposingRulesType }
     * 
     * @return
     *     the new instance of {@link ExposingRulesType }
     */
    public ExposingRulesType createExposingRulesType() {
        return new ExposingRulesType();
    }

    /**
     * Create an instance of {@link Component.PropertiesPreferred }
     * 
     * @return
     *     the new instance of {@link Component.PropertiesPreferred }
     */
    public Component.PropertiesPreferred createComponentPropertiesPreferred() {
        return new Component.PropertiesPreferred();
    }

    /**
     * Create an instance of {@link Component.PropertiesNormal }
     * 
     * @return
     *     the new instance of {@link Component.PropertiesNormal }
     */
    public Component.PropertiesNormal createComponentPropertiesNormal() {
        return new Component.PropertiesNormal();
    }

    /**
     * Create an instance of {@link Component.PropertiesAdvanced }
     * 
     * @return
     *     the new instance of {@link Component.PropertiesAdvanced }
     */
    public Component.PropertiesAdvanced createComponentPropertiesAdvanced() {
        return new Component.PropertiesAdvanced();
    }

    /**
     * Create an instance of {@link Component.PropertiesHidden }
     * 
     * @return
     *     the new instance of {@link Component.PropertiesHidden }
     */
    public Component.PropertiesHidden createComponentPropertiesHidden() {
        return new Component.PropertiesHidden();
    }

    /**
     * Create an instance of {@link Component.PropertiesNoDefaultValue }
     * 
     * @return
     *     the new instance of {@link Component.PropertiesNoDefaultValue }
     */
    public Component.PropertiesNoDefaultValue createComponentPropertiesNoDefaultValue() {
        return new Component.PropertiesNoDefaultValue();
    }

    /**
     * Create an instance of {@link Component.PropertyTag }
     * 
     * @return
     *     the new instance of {@link Component.PropertyTag }
     */
    public Component.PropertyTag createComponentPropertyTag() {
        return new Component.PropertyTag();
    }

    /**
     * Create an instance of {@link Component.MethodSingleProperty }
     * 
     * @return
     *     the new instance of {@link Component.MethodSingleProperty }
     */
    public Component.MethodSingleProperty createComponentMethodSingleProperty() {
        return new Component.MethodSingleProperty();
    }

    /**
     * Create an instance of {@link Component.MethodProperty }
     * 
     * @return
     *     the new instance of {@link Component.MethodProperty }
     */
    public Component.MethodProperty createComponentMethodProperty() {
        return new Component.MethodProperty();
    }

    /**
     * Create an instance of {@link PropertyConfiguration }
     * 
     * @return
     *     the new instance of {@link PropertyConfiguration }
     */
    public PropertyConfiguration createPropertyConfiguration() {
        return new PropertyConfiguration();
    }

    /**
     * Create an instance of {@link ConfigurablePropertyType }
     * 
     * @return
     *     the new instance of {@link ConfigurablePropertyType }
     */
    public ConfigurablePropertyType createConfigurablePropertyType() {
        return new ConfigurablePropertyType();
    }

    /**
     * Create an instance of {@link TypeParametersType }
     * 
     * @return
     *     the new instance of {@link TypeParametersType }
     */
    public TypeParametersType createTypeParametersType() {
        return new TypeParametersType();
    }

    /**
     * Create an instance of {@link TypeParameterType }
     * 
     * @return
     *     the new instance of {@link TypeParameterType }
     */
    public TypeParameterType createTypeParameterType() {
        return new TypeParameterType();
    }

    /**
     * Create an instance of {@link XAttributeType }
     * 
     * @return
     *     the new instance of {@link XAttributeType }
     */
    public XAttributeType createXAttributeType() {
        return new XAttributeType();
    }

    /**
     * Create an instance of {@link MethodParameter }
     * 
     * @return
     *     the new instance of {@link MethodParameter }
     */
    public MethodParameter createMethodParameter() {
        return new MethodParameter();
    }

    /**
     * Create an instance of {@link PropertyEditor }
     * 
     * @return
     *     the new instance of {@link PropertyEditor }
     */
    public PropertyEditor createPropertyEditor() {
        return new PropertyEditor();
    }

    /**
     * Create an instance of {@link ExposingRuleType }
     * 
     * @return
     *     the new instance of {@link ExposingRuleType }
     */
    public ExposingRuleType createExposingRuleType() {
        return new ExposingRuleType();
    }

    /**
     * Create an instance of {@link TagType }
     * 
     * @return
     *     the new instance of {@link TagType }
     */
    public TagType createTagType() {
        return new TagType();
    }

    /**
     * Create an instance of {@link ParameterBaseType.Parameter }
     * 
     * @return
     *     the new instance of {@link ParameterBaseType.Parameter }
     */
    public ParameterBaseType.Parameter createParameterBaseTypeParameter() {
        return new ParameterBaseType.Parameter();
    }

    /**
     * Create an instance of {@link ParameterBaseType.ParameterList }
     * 
     * @return
     *     the new instance of {@link ParameterBaseType.ParameterList }
     */
    public ParameterBaseType.ParameterList createParameterBaseTypeParameterList() {
        return new ParameterBaseType.ParameterList();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Category }
     * 
     * @return
     *     the new instance of {@link PropertyConfigurationElements.Category }
     */
    public PropertyConfigurationElements.Category createPropertyConfigurationElementsCategory() {
        return new PropertyConfigurationElements.Category();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.DefaultValue }
     * 
     * @return
     *     the new instance of {@link PropertyConfigurationElements.DefaultValue }
     */
    public PropertyConfigurationElements.DefaultValue createPropertyConfigurationElementsDefaultValue() {
        return new PropertyConfigurationElements.DefaultValue();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Getter }
     * 
     * @return
     *     the new instance of {@link PropertyConfigurationElements.Getter }
     */
    public PropertyConfigurationElements.Getter createPropertyConfigurationElementsGetter() {
        return new PropertyConfigurationElements.Getter();
    }

    /**
     * Create an instance of {@link PropertyConfigurationElements.Tag }
     * 
     * @return
     *     the new instance of {@link PropertyConfigurationElements.Tag }
     */
    public PropertyConfigurationElements.Tag createPropertyConfigurationElementsTag() {
        return new PropertyConfigurationElements.Tag();
    }

    /**
     * Create an instance of {@link Factory.Method.Invocation }
     * 
     * @return
     *     the new instance of {@link Factory.Method.Invocation }
     */
    public Factory.Method.Invocation createFactoryMethodInvocation() {
        return new Factory.Method.Invocation();
    }

    /**
     * Create an instance of {@link Factory.Method.Parameters.Parameter }
     * 
     * @return
     *     the new instance of {@link Factory.Method.Parameters.Parameter }
     */
    public Factory.Method.Parameters.Parameter createFactoryMethodParametersParameter() {
        return new Factory.Method.Parameters.Parameter();
    }

    /**
     * Create an instance of {@link Component.Parameters.Parameter }
     * 
     * @return
     *     the new instance of {@link Component.Parameters.Parameter }
     */
    public Component.Parameters.Parameter createComponentParametersParameter() {
        return new Component.Parameters.Parameter();
    }

    /**
     * Create an instance of {@link MorphingType.MorphTarget }
     * 
     * @return
     *     the new instance of {@link MorphingType.MorphTarget }
     */
    public MorphingType.MorphTarget createMorphingTypeMorphTarget() {
        return new MorphingType.MorphTarget();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Default }
     * 
     * @return
     *     the new instance of {@link MethodsOrderType.Default }
     */
    public MethodsOrderType.Default createMethodsOrderTypeDefault() {
        return new MethodsOrderType.Default();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Method }
     * 
     * @return
     *     the new instance of {@link MethodsOrderType.Method }
     */
    public MethodsOrderType.Method createMethodsOrderTypeMethod() {
        return new MethodsOrderType.Method();
    }

    /**
     * Create an instance of {@link MethodsOrderType.Methods.S }
     * 
     * @return
     *     the new instance of {@link MethodsOrderType.Methods.S }
     */
    public MethodsOrderType.Methods.S createMethodsOrderTypeMethodsS() {
        return new MethodsOrderType.Methods.S();
    }

    /**
     * Create an instance of {@link Component.Methods.MethodsInclude }
     * 
     * @return
     *     the new instance of {@link Component.Methods.MethodsInclude }
     */
    public Component.Methods.MethodsInclude createComponentMethodsMethodsInclude() {
        return new Component.Methods.MethodsInclude();
    }

    /**
     * Create an instance of {@link Component.Methods.MethodsExclude }
     * 
     * @return
     *     the new instance of {@link Component.Methods.MethodsExclude }
     */
    public Component.Methods.MethodsExclude createComponentMethodsMethodsExclude() {
        return new Component.Methods.MethodsExclude();
    }

    /**
     * Create an instance of {@link Component.Methods.Method }
     * 
     * @return
     *     the new instance of {@link Component.Methods.Method }
     */
    public Component.Methods.Method createComponentMethodsMethod() {
        return new Component.Methods.Method();
    }

    /**
     * Create an instance of {@link Component.Constructors.Constructor }
     * 
     * @return
     *     the new instance of {@link Component.Constructors.Constructor }
     */
    public Component.Constructors.Constructor createComponentConstructorsConstructor() {
        return new Component.Constructors.Constructor();
    }

    /**
     * Create an instance of {@link Creation.Invocation }
     * 
     * @return
     *     the new instance of {@link Creation.Invocation }
     */
    public Creation.Invocation createCreationInvocation() {
        return new Creation.Invocation();
    }

    /**
     * Create an instance of {@link Creation.Parameter }
     * 
     * @return
     *     the new instance of {@link Creation.Parameter }
     */
    public Creation.Parameter createCreationParameter() {
        return new Creation.Parameter();
    }

    /**
     * Create an instance of {@link Creation.XContent }
     * 
     * @return
     *     the new instance of {@link Creation.XContent }
     */
    public Creation.XContent createCreationXContent() {
        return new Creation.XContent();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.eclipse.org/wb/WBPComponent", name = "exclude", scope = ExposingRulesType.class)
    public JAXBElement<ExposingRuleType> createExposingRulesTypeExclude(ExposingRuleType value) {
        return new JAXBElement<>(_ExposingRulesTypeExclude_QNAME, ExposingRuleType.class, ExposingRulesType.class, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExposingRuleType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.eclipse.org/wb/WBPComponent", name = "include", scope = ExposingRulesType.class)
    public JAXBElement<ExposingRuleType> createExposingRulesTypeInclude(ExposingRuleType value) {
        return new JAXBElement<>(_ExposingRulesTypeInclude_QNAME, ExposingRuleType.class, ExposingRulesType.class, value);
    }

}
